@@ -2,12 +2,8 @@ package MyCPAN::Indexer::Component;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-
 use Carp qw(croak);
 
-$VERSION = '1.28_10';
-
 =head1 NAME
 
 MyCPAN::Indexer::Component - base class for MyCPAN components
@@ -126,18 +122,17 @@ sub set_coordinator
 	croak "Coordinator object is missing these methods: @missing"
 		if @missing;
 		
-	$self->{_coordinator} = $coordinator
+	$_[0]->{_coordinator} = $_[1] 
 	}
 	
 }
 
-sub collator_type   { 'collator'   }
-sub dispatcher_type { 'dispatcher' }
-sub indexer_type    { 'indexer'    }
-sub interface_type  { 'interface'  }
 sub queue_type      { 'queue'      }
-sub reporter_type   { 'reporter'   }
+sub dispatcher_type { 'dispatcher' }
 sub worker_type     { 'worker'     }
+sub reporter_type   { 'reporter'   }
+sub interface_type  { 'interface'  }
+sub indexer_type    { 'indexer'    }
 
 =back
 
@@ -153,7 +148,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008-2010, brian d foy, All Rights Reserved.
+Copyright (c) 2008-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
