@@ -4,7 +4,7 @@ use warnings;
 
 use base qw(MyCPAN::Indexer::Reporter::Base);
 use vars qw($VERSION $logger);
-$VERSION = '1.28_10';
+$VERSION = '1.24';
 
 use Carp;
 use File::Basename;
@@ -18,7 +18,7 @@ BEGIN {
 
 =head1 NAME
 
-MyCPAN::Indexer::Reporter::AsYAML - Save the result as a YAML file
+MyCPAN::Indexer::Storage::AsYAML - Save the result as a YAML file
 
 =head1 SYNOPSIS
 
@@ -86,6 +86,16 @@ YAML files, that's C<yml>.
 
 sub get_report_file_extension { 'yml' }
 
+=item final_words( $Notes )
+
+Right before backpan_indexer.pl is about to finish, it calls this method to
+give the reporter a chance to do something at the end. In this case it does
+nothing.
+
+=cut
+
+sub final_words { 1 };
+
 =back
 
 =head1 TO DO
@@ -102,7 +112,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008-2010, brian d foy, All Rights Reserved.
+Copyright (c) 2008-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
